import React, { useContext, useState } from 'react'
import { Typography, Image } from 'antd';
import PendoContext from '../state/PendoContext';
import { Modal } from 'react-bootstrap';
import { useEffect } from 'react';


const { Title } = Typography
export default function Products() {
    const { products, addCart } = useContext(PendoContext)
    const [visible, setVisibility] = useState(false)
    const [value, setValue] = useState(1)
    const [selectedProduct, setProduct] = useState({})
    const scrollToTop = () => window.scrollTo(0, 0);

    useEffect(scrollToTop, [])

    return <>
        <div className="row my-5">
            <div className="col-12">
                <div className="section-title">
                    <h2>Featured Products</h2>
                </div>
            </div>
        </div>
        <Modal show={visible}>
            <Modal.Header className="modal-header">
                <button type="button" className="close" onClick={() => {
                    setVisibility(false)
                }} ><i className="ri-close-fill"></i></button>
            </Modal.Header>
            <Modal.Body>
                <div className="row no-gutters">
                    <div className="col-lg-6 col-md-12 col-sm-12 col-xs-12">
                        <div className="product-gallery">
                            <div className="quickview-slider-active">
                                <div className="single-slider">
                                    <img src={`images/${selectedProduct.image}`} alt="#" />
                                </div>
                                {/* <div className="single-slider">
                                        <img src="images/cookware_set1.jpg" alt="#" />
                                    </div> */}

                            </div>
                        </div>
                    </div>
                    <div className="col-lg-6 col-md-12 col-sm-12 col-xs-12">
                        <div className="quickview-content">
                            <h2>{selectedProduct.name}</h2>
                            <div className="quickview-ratting-review">
                                <div className="quickview-ratting-wrap">
                                    <div className="quickview-ratting">
                                        <i className="ri-star-fill"></i>
                                        <i className="ri-star-fill"></i>
                                        <i className="ri-star-fill"></i>
                                        <i className="ri-star-fill"></i>
                                        <i className="ri-star-line"></i>
                                    </div>
                                    <a href="/#"> (1 customer review)</a>
                                </div>
                                <div className="quickview-stock">
                                    <span><i className="ri-checkbox-circle-fill"></i> in stock</span>
                                </div>
                            </div>
                            <h3>Ksh {selectedProduct.price}</h3>
                            <div className="quickview-peragraph">
                                <p>{selectedProduct.description}</p>
                            </div>
                            <div className="size">
                                <div className="row">
                                    <div className="col-lg-6 col-12">
                                        <h5 className="title">Size</h5>
                                        <select>
                                            <option defaultValue="selected">s</option>
                                            <option>m</option>
                                            <option>l</option>
                                            <option>xl</option>
                                        </select>
                                    </div>
                                    <div className="col-lg-6 col-12">
                                        <h5 className="title">Color</h5>
                                        <select>
                                            <option defaultValue="selected">orange</option>
                                            <option>purple</option>
                                            <option>black</option>
                                            <option>pink</option>
                                        </select>
                                    </div>
                                </div>
                            </div>
                            <div className="quantity">
                                <div className="input-group">
                                    <div className="button minus">
                                        <button type="button" className="btn btn-primary btn-number" onClick={() => {
                                            let val = value
                                            if (val > 1) {
                                                val -= 1
                                            }
                                            setValue(val)
                                        }} >
                                            <i className="ri-subtract-line"></i>
                                        </button>
                                    </div>
                                    <input type="text" className="input-number" value={value} onChange={(e) => {
                                        setValue(e.target.value)
                                    }} />
                                    <div className="button plus">
                                        <button type="button" className="btn btn-primary btn-number" onClick={() => {
                                            let val = value
                                            val += 1
                                            setValue(val)
                                        }}>
                                            <i className="ri-add-fill"></i>
                                        </button>
                                    </div>
                                </div>
                            </div>
                            <div className="add-to-cart">
                                <button className="btn" onClick={() => {
                                    selectedProduct.quantity = value
                                    addCart(selectedProduct)
                                    setVisibility(false)
                                    scrollToTop()
                                }}>Add to cart</button>
                            </div>
                        </div>
                    </div>
                </div>
            </Modal.Body>
        </Modal>
        <div className="d-flex justify-content-around flex-wrap">
            {
                products.map(product => {
                    let src = `images/${product.image}`;
                    return <div key={parseInt(product.id)} className="d-flex flex-column  align-items-center product">
                        <Image src={src} height={300} />
                        <p className="product__name">{product.name}</p>
                        <Title className="product__price" level={5}>Ksh {product.price}</Title>
                        {product.availability ? <p className="product__availability_true">In Stock</p> : <p className="product__availability_false">Out of Stock</p>}
                        <button onClick={() => {
                            setProduct(product)
                            setVisibility(true)
                        }
                        } className="product__button">ADD TO CART</button>
                    </div>
                })
            }

        </div>
    </>
}